import { Observable } from 'rxjs';
export interface ITrackingInfo {
    statusLabel: string;
    statusPercentage: number;
    detailsLink: string | undefined;
    carrierName: string;
}
/**
 * The base class to track packages
 */
export declare abstract class PackageTracker {
    carrierName: string;
    /**
     * Given a tracking number should return an observable that resolve to:
     * - true if the tracking number is from this carrier
     * - false otherwise
     * @param trackingNumber
     */
    trackingNumber: string;
    constructor(trackingNumber: string);
    track(): Observable<ITrackingInfo>;
    abstract isTrackingNumberFromCarrier(): Observable<boolean>;
    /**
     * Given a tracking number,
     * Will get tracking information
     * requires:
     * ----------
     * @param trackingNumber
     * ensure:
     * -------
     * An observable that resolves with the carrier server response
     */
    protected abstract getPackageInformationFromCarrier(): Observable<any>;
    /**
     * Convert response from carrier to an ITrackingInfo
     * @param response
     */
    protected abstract resolveCarrierResponseToITrackingInfo(response: any): ITrackingInfo;
}
